@@ -6,8 +6,10 @@ from .const import SwitchbotModel
 from .devices.base_light import SwitchbotBaseLight
 from .devices.bot import Switchbot
 from .devices.bulb import SwitchbotBulb
+from .devices.ceiling_light import SwitchbotCeilingLight
 from .devices.curtain import SwitchbotCurtain
 from .devices.device import ColorMode, SwitchbotDevice
+from .devices.humidifer import SwitchbotHumidifier
 from .devices.light_strip import SwitchbotLightStrip
 from .devices.plug import SwitchbotPlugMini
 from .discovery import GetSwitchbotDevices
@@ -20,9 +22,11 @@ __all__ = [
     "ColorMode",
     "SwitchbotBaseLight",
     "SwitchbotBulb",
+    "SwitchbotCeilingLight",
     "SwitchbotDevice",
     "SwitchbotCurtain",
     "SwitchbotLightStrip",
+    "SwitchbotHumidifier",
     "Switchbot",
     "SwitchbotPlugMini",
     "SwitchbotSupportedType",
