@@ -1,7 +1,6 @@
 """Library to handle connection with Switchbot."""
 from __future__ import annotations
 
-import logging
 from typing import Any
 
 from .device import DEVICE_SET_EXTENDED_KEY, DEVICE_SET_MODE_KEY, SwitchbotDevice
@@ -14,9 +13,6 @@ DOWN_KEY = "570103"
 UP_KEY = "570104"
 
 
-_LOGGER = logging.getLogger(__name__)
-
-
 class Switchbot(SwitchbotDevice):
     """Representation of a Switchbot."""
 
