@@ -1,19 +1,15 @@
 from __future__ import annotations
 
-import asyncio
 import logging
-from enum import Enum
 from typing import Any
 
-from switchbot.models import SwitchBotAdvertisement
+from .base_light import SwitchbotSequenceBaseLight
+from .device import REQ_HEADER, ColorMode
 
-from .device import SwitchbotDevice, SwitchbotSequenceDevice
-
-REQ_HEADER = "570f"
-BULB_COMMMAND_HEADER = "4701"
+BULB_COMMAND_HEADER = "4701"
 BULB_REQUEST = f"{REQ_HEADER}4801"
 
-BULB_COMMAND = f"{REQ_HEADER}{BULB_COMMMAND_HEADER}"
+BULB_COMMAND = f"{REQ_HEADER}{BULB_COMMAND_HEADER}"
 # Bulb keys
 BULB_ON_KEY = f"{BULB_COMMAND}01"
 BULB_OFF_KEY = f"{BULB_COMMAND}02"
@@ -25,11 +21,8 @@ CW_KEY = f"{BULB_COMMAND}17"
 
 _LOGGER = logging.getLogger(__name__)
 
-from .base_light import SwitchbotBaseLight
-from .device import ColorMode
 
-
-class SwitchbotBulb(SwitchbotBaseLight):
+class SwitchbotBulb(SwitchbotSequenceBaseLight):
     """Representation of a Switchbot bulb."""
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -100,7 +93,5 @@ class SwitchbotBulb(SwitchbotBaseLight):
             "isOn": result[1] == 0x80,
             "color_mode": result[10],
         }
-        _LOGGER.debug(
-            "%s: Bulb update state: %s = %s", self.name, result.hex(), self._state
-        )
+        _LOGGER.debug("%s: update state: %s = %s", self.name, result.hex(), self._state)
         self._fire_callbacks()
