@@ -26,10 +26,13 @@ from ..models import SwitchBotAdvertisement
 
 _LOGGER = logging.getLogger(__name__)
 
+REQ_HEADER = "570f"
+
+
 # Keys common to all device types
 DEVICE_GET_BASIC_SETTINGS_KEY = "5702"
 DEVICE_SET_MODE_KEY = "5703"
-DEVICE_SET_EXTENDED_KEY = "570f"
+DEVICE_SET_EXTENDED_KEY = REQ_HEADER
 
 # Base key when encryption is set
 KEY_PASSWORD_PREFIX = "571"
@@ -423,8 +426,9 @@ class SwitchbotDevice:
     ) -> bool:
         """Check command result."""
         if not result or len(result) - 1 < index:
+            result_hex = result.hex() if result else "None"
             raise SwitchbotOperationError(
-                f"{self.name}: Sending command failed (rssi={self.rssi})"
+                f"{self.name}: Sending command failed (result={result_hex} index={index} expected={values} rssi={self.rssi})"
             )
         return result[index] in values
 
